@@ -1,5 +1,5 @@
 package App::JobLog::Command::when;
-$App::JobLog::Command::when::VERSION = '1.035';
+$App::JobLog::Command::when::VERSION = '1.036';
 # ABSTRACT: when you'll be done for the day
 
 use App::JobLog -command;
@@ -91,7 +91,7 @@ END
             $format = FULL_FORMAT;
         }
         if ( $then < now ) {
-            $then = $days->[-1]->last_event->end->add( seconds => $remaining );
+            $then = ( $days->[-1]->last_event->end // now )->add( seconds => $remaining );
             say "\nyou were finished at " . $then->strftime($format);
         }
         else {
@@ -173,7 +173,7 @@ App::JobLog::Command::when - when you'll be done for the day
 
 =head1 VERSION
 
-version 1.035
+version 1.036
 
 =head1 SYNOPSIS
 
